from pydantic import BaseModel, Field
from typing import Optional
from datetime import datetime
import uuid

class BookBase(BaseModel):
    title: str = Field(..., description="Book title")
    author: str = Field(..., description="Book author")
    description: Optional[str] = Field(None, description="Book description")
    pages: Optional[int] = Field(None, description="Number of pages")

class BookCreate(BookBase):
    pass

class BookUpdate(BookBase):
    title: Optional[str] = Field(None, description="Book title")
    author: Optional[str] = Field(None, description="Book author")
    description: Optional[str] = Field(None, description="Book description")
    pages: Optional[int] = Field(None, description="Number of pages")

class BookSchema(BookBase):
    id: uuid.UUID
    created_at: datetime
    updated_at: datetime

    class Config:
        orm_mode = True